==> nextcloud-12.0.3.zip: nextcloud/apps/gallery/l10n/kn.js <==
OC.L10N.register(
    "gallery",
    {
    "New" : "﻿ಹೊಸ",
    "Next" : "ಮುಂದೆ",
    "Close" : "ಮುಚ್ಚು",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "File name cannot be empty." : "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
    "Upload" : "ವರ್ಗಾಯಿಸಿ",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "Error while sharing" : "ಹಂಚುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Error while unsharing" : " ಹಂಚಿಕೆಯನ್ನು ಹಿಂದೆರುಗಿಸು ಸಂದರ್ಭದಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
    "Error while changing permissions" : "ಅನುಮತಿಗಳನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷವಾಗಿದೆ",
    "Shared with you and the group {group} by {owner}" : "ನಿಮಗೆ ಮತ್ತು {group} ಗುಂಪಿನೂಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
    "Shared with you by {owner}" : "﻿ನಿಮ್ಮೊಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
    "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "The public link will expire no later than {days} days after it is created" : "﻿ರಚನೆಯಾದ {days} ದಿನಗಳ ನಂತರ ಈ ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿ ಅಂತ್ಯಗೊಳ್ಳಲಿದೆ",
    "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
    "Password protect" : "﻿ಗುಪ್ತಪದ ರಕ್ಷಿಸಿಕೂಳ್ಲಿ",
    "Password" : "ಗುಪ್ತಪದ",
    "Choose a password for the public link" : "ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿಗೆ ಗುಪ್ತಪದ ಆಯ್ಕೆಮಾಡಿ",
    "Allow editing" : "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
    "Email link to person" : "ಬಳಕೆದಾರನ ಇ-ಅಂಚೆಯ ಸಂಪರ್ಕಕೊಂಡಿ",
    "Send" : "﻿ಕಳುಹಿಸಿ",
    "Set expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸಿ",
    "Expiration" : "﻿ಮುಕ್ತಾಯ",
    "Expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕ",
    "Adding user..." : "﻿ಬಳಕೆದಾರನನ್ನು ಸೇರಿಸಲಾಗುತ್ತಿದೆ ...",
    "group" : "﻿ಗುಂಪು",
    "remote" : "ಆಚೆಯ",
    "Resharing is not allowed" : "﻿ಮರುಹಂಚಿಕೆ ಅನುಮತಿಸಲಾಗುವುದಿಲ್ಲ",
    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
    "notify by email" : "﻿ಇ-ಅಂಚೆ ಮೂಲಕ ತಿಳಿಸಲು",
    "can share" : "﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
    "access control" : "﻿ಪ್ರವೇಶ ನಿಯಂತ್ರಣ",
    "create" : "ಸೃಷ್ಟಿಸು",
    "change" : "﻿ಬದಲಾವಣೆ",
    "delete" : "﻿ಅಳಿಸಿ",
    "Password protected" : "ಗುಪ್ತಪದದಿಂದ ರಕ್ಷಿಸಲಾಗಿದೆ",
    "Error unsetting expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಹಿಂಪಡೆಯುವಲಿ್ಲ ದೋಷ",
    "Error setting expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸುವಲ್ಲಿ ದೋಷ",
    "Sending ..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "Warning" : "﻿ಎಚ್ಚರಿಕೆ",
    "Cancel upload" : "﻿ವರ್ಗಾವಣೆ ರದ್ದು ಮಾಡಿ"
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.13.zip: nextcloud/apps/gallery/l10n/kn.js <==
OC.L10N.register(
    "gallery",
    {
    "Next" : "ಮುಂದೆ",
    "Close" : "ಮುಚ್ಚು",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
    "File name cannot be empty." : "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
    "Upload" : "ವರ್ಗಾಯಿಸಿ",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "Error while sharing" : "ಹಂಚುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Error while unsharing" : " ಹಂಚಿಕೆಯನ್ನು ಹಿಂದೆರುಗಿಸು ಸಂದರ್ಭದಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
    "Error while changing permissions" : "ಅನುಮತಿಗಳನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷವಾಗಿದೆ",
    "Shared with you and the group {group} by {owner}" : "ನಿಮಗೆ ಮತ್ತು {group} ಗುಂಪಿನೂಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
    "Shared with you by {owner}" : "﻿ನಿಮ್ಮೊಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
    "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "The public link will expire no later than {days} days after it is created" : "﻿ರಚನೆಯಾದ {days} ದಿನಗಳ ನಂತರ ಈ ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿ ಅಂತ್ಯಗೊಳ್ಳಲಿದೆ",
    "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
    "Password protect" : "﻿ಗುಪ್ತಪದ ರಕ್ಷಿಸಿಕೂಳ್ಲಿ",
    "Password" : "ಗುಪ್ತಪದ",
    "Choose a password for the public link" : "ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿಗೆ ಗುಪ್ತಪದ ಆಯ್ಕೆಮಾಡಿ",
    "Allow editing" : "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
    "Email link to person" : "ಬಳಕೆದಾರನ ಇ-ಅಂಚೆಯ ಸಂಪರ್ಕಕೊಂಡಿ",
    "Send" : "﻿ಕಳುಹಿಸಿ",
    "Set expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸಿ",
    "Expiration" : "﻿ಮುಕ್ತಾಯ",
    "Expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕ",
    "Adding user..." : "﻿ಬಳಕೆದಾರನನ್ನು ಸೇರಿಸಲಾಗುತ್ತಿದೆ ...",
    "group" : "﻿ಗುಂಪು",
    "remote" : "ಆಚೆಯ",
    "Resharing is not allowed" : "﻿ಮರುಹಂಚಿಕೆ ಅನುಮತಿಸಲಾಗುವುದಿಲ್ಲ",
    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
    "notify by email" : "﻿ಇ-ಅಂಚೆ ಮೂಲಕ ತಿಳಿಸಲು",
    "can share" : "﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
    "access control" : "﻿ಪ್ರವೇಶ ನಿಯಂತ್ರಣ",
    "create" : "ಸೃಷ್ಟಿಸು",
    "change" : "﻿ಬದಲಾವಣೆ",
    "delete" : "﻿ಅಳಿಸಿ",
    "Password protected" : "ಗುಪ್ತಪದದಿಂದ ರಕ್ಷಿಸಲಾಗಿದೆ",
    "Error unsetting expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಹಿಂಪಡೆಯುವಲಿ್ಲ ದೋಷ",
    "Error setting expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸುವಲ್ಲಿ ದೋಷ",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "Warning" : "﻿ಎಚ್ಚರಿಕೆ",
    "Cancel upload" : "﻿ವರ್ಗಾವಣೆ ರದ್ದು ಮಾಡಿ",
    "New" : "﻿ಹೊಸ"
},
"nplurals=2; plural=(n > 1);");
